@@ -162,24 +162,17 @@ action_template_post = {
     "properties": {
         "name": {"type": "string",
                  "maxLength": 40},
-        "description": {"type": "string"},
+        "description": Multiline,
         "action_type": {"type": "string",
                         "pattern": action_type_pattern},
-        "code": {"anyOf": [{"type": "string"},
-                           {"type": "array",
-                            "items": {"type": "string"}}]},
-        "parameters": {"type": "object"},
+        "code": Multiline,
         "schema": schema,
-        "expected_stdout": {"type": "string"},
-        "expected_stderr": {"type": "string"},
+        "expected_stdout": Multiline,
+        "expected_stderr": Multiline,
         "expected_rc": {"type": "integer"},
         "system_kwargs": {"type": "object"},
-        "pre_process": {"anyOf": [{"type": "string"},
-                                  {"type": "array",
-                                   "items": {"type": "string"}}]},
-        "post_process": {"anyOf": [{"type": "string"},
-                                   {"type": "array",
-                                    "items": {"type": "string"}}]},
+        "pre_process": Multiline,
+        "post_process": Multiline,
     },
     "if": {
         "properties": {"action_type": {"const": "SEND"}}
@@ -188,9 +181,7 @@ action_template_post = {
         "required": ["name", "action_type"],
     },
     "else": {
-        "properties": {"code": {"anyOf": [{"type": "string"},
-                                          {"type": "array",
-                                           "items": {"type": "string"}}]}},
+        "properties": {"code": Multiline},
         "required": ["name", "action_type", "code"],
     },
     "required": ["name", "action_type", "code"],
@@ -200,28 +191,17 @@ action_template_post = {
 action_template_patch = {
     "type": "object",
     "properties": {
-        "description": {"type": "string"},
+        "description": Multiline,
         "action_type": {"type": "string",
                         "pattern": f"^({'|'.join([at.name for at in ActionType])})$"},
-        "code": {"anyOf": [{"type": "string"},
-                           {"type": "array",
-                            "items": {"type": "string"}}]},
-        "parameters": {"type": "object"},
+        "code": Multiline,
         "schema": schema,
-        "expected_stdout": {"anyOf": [{"type": "string"},
-                                      {"type": "array",
-                                       "items": {"type": "string"}}]},
-        "expected_stderr": {"anyOf": [{"type": "string"},
-                                      {"type": "array",
-                                       "items": {"type": "string"}}]},
+        "expected_stdout": Multiline,
+        "expected_stderr": Multiline,
         "expected_rc": {"type": "integer"},
         "system_kwargs": {"type": "object"},
-        "pre_process": {"anyOf": [{"type": "string"},
-                                  {"type": "array",
-                                   "items": {"type": "string"}}]},
-        "post_process": {"anyOf": [{"type": "string"},
-                                   {"type": "array",
-                                    "items": {"type": "string"}}]},
+        "pre_process": Multiline,
+        "post_process": Multiline,
     },
     "additionalProperties": False
 }
@@ -235,26 +215,21 @@ _step_post = {
         "undo": {"type": "boolean"},
         "name": {"type": "string",
                  "maxLength": 40},
-        "description": {"type": "string"},
+        "description": Multiline,
         "stop_on_error": {"type": "boolean"},
         "stop_undo_on_error": {"type": "boolean"},
         "action_template_id": Id,
         "action_type": {"type": "string",
                         "pattern": action_type_pattern},
         "undo_on_error": {"type": "boolean"},
-        "code": {"anyOf": [{"type": "string"},
-                           {"type": "array",
-                            "items": {"type": "string"}}]},
-        "parameters": {"type": "object"},
+        "code": Multiline,
         "schema": schema,
         "expected_stdout": Multiline,
         "expected_stderr": Multiline,
         "expected_rc": {"type": "integer"},
         "system_kwargs": {"type": "object"},
         "pre_process": Multiline,
-        "post_process": {"anyOf": [{"type": "string"},
-                                   {"type": "array",
-                                    "items": {"type": "string"}}]},
+        "post_process": Multiline,
         "parent_step_ids": {"type": "array",
                             "items": {"anyOf": [Id,
                                                 {"type": "integer", "minimum": 1}]
@@ -287,28 +262,17 @@ step_put = {
         "action_type": {"type": "string",
                         "pattern": action_type_pattern},
 
-        "code": {"anyOf": [{"type": "string"},
-                           {"type": "array",
-                            "items": {"type": "string"}}]},
-        "parameters": {"type": "object"},
+        "code": Multiline,
         "schema": schema,
-        "expected_stdout": {"anyOf": [{"type": "string"},
-                                      {"type": "array",
-                                       "items": {"type": "string"}}]},
-        "expected_stderr": {"anyOf": [{"type": "string"},
-                                      {"type": "array",
-                                       "items": {"type": "string"}}]},
+        "expected_stdout": Multiline,
+        "expected_stderr": Multiline,
         "expected_rc": {"type": "integer"},
         "system_kwargs": {"type": "object"},
-        "pre_process": {"anyOf": [{"type": "string"},
-                                  {"type": "array",
-                                   "items": {"type": "string"}}]},
-        "post_process": {"anyOf": [{"type": "string"},
-                                   {"type": "array",
-                                    "items": {"type": "string"}}]},
+        "pre_process": Multiline,
+        "post_process": Multiline,
         "name": {"type": "string",
                  "maxLength": 40},
-        "description": {"type": "string"},
+        "description": Multiline,
         "parent_step_ids": {"type": "array",
                             "items": {"anyOf": [Id,
                                                 {"type": "integer", "minimum": 1}]
